# GetMachineTypeLiveUtilizationResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**cpu_utilization** | **float** |  | 
**gpu_free** | **int** |  | 
**gpu_total** | **int** |  | 
**gpu_used** | **int** |  | 
**gpu_utilization** | **float** |  | 
**memory_gib_free** | **int** |  | 
**memory_gib_total** | **int** |  | 
**memory_gib_used** | **int** |  | 
**memory_utilization** | **float** |  | 
**utilization** | **float** |  | 
**vcpu_free** | **int** |  | 
**vcpu_total** | **int** |  | 
**vcpu_used** | **int** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


